pub enum NonStrictExpression {
Sync(Arc<dyn SyncExpression>),
Async(Arc<dyn AsyncDynExpression>),
}Expand description
An type-safe wrapper that indicates the inner expression can be evaluated in a non-strict
manner, i.e., developers can directly call eval_infallible and eval_row_infallible without
checking the result.
This is usually created by non-strict build functions like crate::expr::build_non_strict_from_prost
and crate::expr::build_func_non_strict. It can also be created directly by
NonStrictExpression::new_topmost, where only the evaluation of the topmost level expression
node is non-strict and should be treated as a TODO.
Compared to crate::expr::wrapper::non_strict::NonStrict, this is more like an indicator
applied on the root of an expression tree, while the latter is a wrapper that can be applied on
each node of the tree and actually changes the behavior. As a result, NonStrictExpression
does not implement expression traits and instead deals directly with developers.
Variants
Sync(Arc<dyn SyncExpression>)
Async(Arc<dyn AsyncDynExpression>)
Implementations
Sourceimpl NonStrictExpression
impl NonStrictExpression
Sourcepub fn for_test(inner: impl Into<BoxedExpression>) -> NonStrictExpression
pub fn for_test(inner: impl Into<BoxedExpression>) -> NonStrictExpression
Create a non-strict expression directly wrapping the given expression.
Should only be used in tests as evaluation may panic.
Sourcepub fn new_topmost(
inner: impl Into<BoxedExpression>,
error_report: impl EvalErrorReport + 'static,
) -> NonStrictExpression
pub fn new_topmost( inner: impl Into<BoxedExpression>, error_report: impl EvalErrorReport + 'static, ) -> NonStrictExpression
Create a non-strict expression from the given expression, where only the evaluation of the
topmost level expression node is non-strict (which is subtly different from
crate::expr::build_non_strict_from_prost where every node is non-strict).
This should be used as a TODO.
Sourcepub fn return_type(&self) -> DataType
pub fn return_type(&self) -> DataType
Get the return data type.
Sourcepub async fn eval_infallible(&self, input: &DataChunk) -> ArrayRef
pub async fn eval_infallible(&self, input: &DataChunk) -> ArrayRef
Evaluate the expression in vectorized execution and assert it succeeds. Returns an array.
Use with expressions built in non-strict mode.
Sourcepub async fn eval_row_infallible(&self, input: &OwnedRow) -> Datum
pub async fn eval_row_infallible(&self, input: &OwnedRow) -> Datum
Evaluate the expression in row-based execution and assert it succeeds. Returns a nullable scalar.
Use with expressions built in non-strict mode.
Sourcepub fn into_inner(self) -> BoxedExpression
pub fn into_inner(self) -> BoxedExpression
Unwrap the inner expression.
Sourcepub fn inner(&self) -> &dyn ExpressionInfo
pub fn inner(&self) -> &dyn ExpressionInfo
Get a reference to the inner expression.