pub fn try_convert_all<T, U>(
items: Vec<T>,
try_convert: impl FnMut(T) -> Result<U, T>,
recover: impl Fn(U) -> T,
) -> Result<Vec<U>, Vec<T>>Expand description
Try to convert all items in a vector, or return the original vector if any conversion fails.