pub struct RangeFrameOffset {
offset: ScalarImpl,
add_expr: Option<Arc<dyn SyncExpression>>,
sub_expr: Option<Arc<dyn SyncExpression>>,
}Expand description
The wrapper type for ScalarImpl range frame offset, containing
two expressions to help adding and subtracting the offset.
Fields
offset: ScalarImplThe original offset value.
add_expr: Option<Arc<dyn SyncExpression>>Built expression for $0 + offset.
sub_expr: Option<Arc<dyn SyncExpression>>Built expression for $0 - offset.
Implementations
Sourceimpl RangeFrameOffset
impl RangeFrameOffset
pub fn new(offset: ScalarImpl) -> Self
fn prepare( &mut self, order_data_type: &DataType, offset_data_type: &DataType, ) -> Result<()>
pub fn new_for_test( offset: ScalarImpl, order_data_type: &DataType, offset_data_type: &DataType, ) -> Self
Methods from Deref<Target = ScalarImpl>
pub fn get_ident(&self) -> &'static str
Sourcepub fn successor(&self) -> Option<ScalarImpl>
pub fn successor(&self) -> Option<ScalarImpl>
Returns the successor of the current value if it exists.
See also Successor.
The function may return None when:
- The current value is the maximum value of the type.
- The successor value of the type is not well-defined.
Sourcepub fn as_float32(&self) -> &OrderedFloat<f32>
pub fn as_float32(&self) -> &OrderedFloat<f32>
Panics
If the scalar is not of the expected type.
Sourcepub fn as_float64(&self) -> &OrderedFloat<f64>
pub fn as_float64(&self) -> &OrderedFloat<f64>
Panics
If the scalar is not of the expected type.
Sourcepub fn as_decimal(&self) -> &Decimal
pub fn as_decimal(&self) -> &Decimal
Panics
If the scalar is not of the expected type.
Sourcepub fn as_interval(&self) -> &Interval
pub fn as_interval(&self) -> &Interval
Panics
If the scalar is not of the expected type.
Sourcepub fn as_timestamp(&self) -> &Timestamp
pub fn as_timestamp(&self) -> &Timestamp
Panics
If the scalar is not of the expected type.
Sourcepub fn as_timestamptz(&self) -> &Timestamptz
pub fn as_timestamptz(&self) -> &Timestamptz
Panics
If the scalar is not of the expected type.
Sourcepub fn as_variant(&self) -> &VariantVal
pub fn as_variant(&self) -> &VariantVal
Panics
If the scalar is not of the expected type.
Sourcepub fn as_struct(&self) -> &StructValue
pub fn as_struct(&self) -> &StructValue
Panics
If the scalar is not of the expected type.
Sourcepub fn as_vector(&self) -> &VectorInner<Box<[OrderedFloat<f32>]>>
pub fn as_vector(&self) -> &VectorInner<Box<[OrderedFloat<f32>]>>
Panics
If the scalar is not of the expected type.
Sourcepub fn as_scalar_ref_impl(&self) -> ScalarRefImpl<'_>
pub fn as_scalar_ref_impl(&self) -> ScalarRefImpl<'_>
Converts ScalarImpl to ScalarRefImpl
Sourcepub fn serialize(&self, ser: &mut Serializer<impl BufMut>) -> Result<(), Error>
pub fn serialize(&self, ser: &mut Serializer<impl BufMut>) -> Result<(), Error>
Serialize the scalar into the memcomparable format.
pub fn as_integral(&self) -> i64