pub trait AsyncDynExpression: ExpressionInfo {
// Required methods
fn eval<'life0, 'life1, 'async_trait>(
&'life0 self,
input: &'life1 DataChunk,
) -> Pin<Box<dyn Future<Output = Result<ArrayRef>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn eval_v2<'life0, 'life1, 'async_trait>(
&'life0 self,
input: &'life1 DataChunk,
) -> Pin<Box<dyn Future<Output = Result<ValueImpl>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn eval_row<'life0, 'life1, 'async_trait>(
&'life0 self,
input: &'life1 OwnedRow,
) -> Pin<Box<dyn Future<Output = Result<Datum>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
}Expand description
Object-safe adapter for asynchronous expressions.
Required Methods
Sourcefn eval<'life0, 'life1, 'async_trait>(
&'life0 self,
input: &'life1 DataChunk,
) -> Pin<Box<dyn Future<Output = Result<ArrayRef>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn eval<'life0, 'life1, 'async_trait>(
&'life0 self,
input: &'life1 DataChunk,
) -> Pin<Box<dyn Future<Output = Result<ArrayRef>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Evaluate the expression in vectorized execution. Returns an array.
Sourcefn eval_v2<'life0, 'life1, 'async_trait>(
&'life0 self,
input: &'life1 DataChunk,
) -> Pin<Box<dyn Future<Output = Result<ValueImpl>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn eval_v2<'life0, 'life1, 'async_trait>(
&'life0 self,
input: &'life1 DataChunk,
) -> Pin<Box<dyn Future<Output = Result<ValueImpl>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Evaluate the expression in vectorized execution. Returns a value that can be either an array, or a scalar if all values in the array are the same.
Sourcefn eval_row<'life0, 'life1, 'async_trait>(
&'life0 self,
input: &'life1 OwnedRow,
) -> Pin<Box<dyn Future<Output = Result<Datum>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn eval_row<'life0, 'life1, 'async_trait>(
&'life0 self,
input: &'life1 OwnedRow,
) -> Pin<Box<dyn Future<Output = Result<Datum>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Evaluate the expression in row-based execution. Returns a nullable scalar.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".